"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const amount_pb_1 = require("../Generated/web/org/xrpl/rpc/v1/amount_pb");
const xrp_issued_currency_1 = __importDefault(require("./xrp-issued-currency"));
/**
 * An amount of currency on the XRP Ledger
 * @see: https://xrpl.org/basic-data-types.html#specifying-currency-amounts
 */
class XrpCurrencyAmount {
    /**
     * Note: Mutually exclusive fields - only drops XOR issuedCurrency should be set.
     *
     * @param drops An amount of XRP, specified in drops.
     * @param issuedCurrency An amount of an issued currency.
     */
    constructor(drops, issuedCurrency) {
        this.drops = drops;
        this.issuedCurrency = issuedCurrency;
    }
    /**
     * Constructs an XrpCurrencyAmount from a CurrencyAmount.
     *
     * @param currencyAmount a CurrencyAmount (protobuf object) whose field values will be used
     *                       to construct an XrpCurrencyAmount
     * @returns an XrpCurrencyAmount with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/develop/src/ripple/proto/org/xrpl/rpc/v1/amount.proto#L10
     */
    static from(currencyAmount) {
        var _a;
        switch (currencyAmount.getAmountCase()) {
            // Mutually exclusive: either drops or issuedCurrency is set in an XRPCurrencyAmount
            case amount_pb_1.CurrencyAmount.AmountCase.ISSUED_CURRENCY_AMOUNT: {
                const issuedCurrencyAmount = currencyAmount.getIssuedCurrencyAmount();
                if (issuedCurrencyAmount) {
                    const issuedCurrency = xrp_issued_currency_1.default.from(issuedCurrencyAmount);
                    if (issuedCurrency) {
                        return new XrpCurrencyAmount(undefined, issuedCurrency);
                    }
                }
                return undefined;
            }
            case amount_pb_1.CurrencyAmount.AmountCase.XRP_AMOUNT: {
                const drops = (_a = currencyAmount.getXrpAmount()) === null || _a === void 0 ? void 0 : _a.getDrops();
                if (drops) {
                    return new XrpCurrencyAmount(drops, undefined);
                }
                return undefined;
            }
            default:
                return undefined;
        }
    }
}
exports.default = XrpCurrencyAmount;
//# sourceMappingURL=xrp-currency-amount.js.map