"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Represents a SignerEntry object on the XRP Ledger.
 *
 * @see: https://xrpl.org/signerlist.html#signerentry-object
 */
class XrpSignerEntry {
    /**
     * @param account An XRP Ledger address whose signature contributes to the multi-signature.
     *                It does not need to be a funded address in the ledger.
     * @param signerWeight The weight of a signature from this signer. A multi-signature is only valid if the sum
     *                     weight of the signatures provided meets or exceeds the SignerList's SignerQuorum value.
     */
    constructor(account, signerWeight) {
        this.account = account;
        this.signerWeight = signerWeight;
    }
    /**
     * Constructs an XrpSignerEntry from a SignerEntry protocol buffer.
     *
     * @param signerEntry a SignerEntry (protobuf object) whose field values will be used to construct an XrpSignerEntry
     * @return an XrpSignerEntry with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/f43aeda49c5362dc83c66507cae2ec71cfa7bfdf/src/ripple/proto/org/xrpl/rpc/v1/common.proto#L471
     */
    static from(signerEntry) {
        var _a, _b, _c;
        const account = (_b = (_a = signerEntry.getAccount()) === null || _a === void 0 ? void 0 : _a.getValue()) === null || _b === void 0 ? void 0 : _b.getAddress();
        const signerWeight = (_c = signerEntry.getSignerWeight()) === null || _c === void 0 ? void 0 : _c.getValue();
        if (!account || !signerWeight) {
            return undefined;
        }
        return new XrpSignerEntry(account, signerWeight);
    }
}
exports.default = XrpSignerEntry;
//# sourceMappingURL=xrp-signer-entry.js.map